Customalert class

Constructors

Customalert()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context, {required String message, required Duration closeduration, required Color backgroundColor, required TextStyle textStyle, required bool isIcon, Icon icn = const Icon(Icons.check_circle, color: Colors.green, size: 30)}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited